==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewayFirewallDisabledRuleGroupArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewayFirewallDisabledRuleGroupArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Allows to disable rules within a rule group or an entire rule group.
 * @property ruleGroupName The name of the rule group that will be disabled.
 * @property rules The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
 */
public data class ApplicationGatewayFirewallDisabledRuleGroupArgs(
    public val ruleGroupName: Output<String>,
    public val rules: Output<List<Int>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewayFirewallDisabledRuleGroupArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ApplicationGatewayFirewallDisabledRuleGroupArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewayFirewallDisabledRuleGroupArgs.builder()
            .ruleGroupName(ruleGroupName.applyValue({ args0 -> args0 }))
            .rules(rules?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ApplicationGatewayFirewallDisabledRuleGroupArgs].
 */
@PulumiTagMarker
public class ApplicationGatewayFirewallDisabledRuleGroupArgsBuilder internal constructor() {
    private var ruleGroupName: Output<String>? = null

    private var rules: Output<List<Int>>? = null

    /**
     * @param value The name of the rule group that will be disabled.
     */
    @JvmName("wbudnvubkegaqhka")
    public suspend fun ruleGroupName(`value`: Output<String>) {
        this.ruleGroupName = value
    }

    /**
     * @param value The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
     */
    @JvmName("xpxowvbhjptxvjbq")
    public suspend fun rules(`value`: Output<List<Int>>) {
        this.rules = value
    }

    @JvmName("pujduicgdpptilph")
    public suspend fun rules(vararg values: Output<Int>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
     */
    @JvmName("qsgdcbygxcsqnmqc")
    public suspend fun rules(values: List<Output<Int>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value The name of the rule group that will be disabled.
     */
    @JvmName("jfwlgngfajmkosir")
    public suspend fun ruleGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleGroupName = mapped
    }

    /**
     * @param value The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
     */
    @JvmName("fuejilbahutlpwta")
    public suspend fun rules(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param values The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
     */
    @JvmName("rfeedtuhkjxmjhpg")
    public suspend fun rules(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): ApplicationGatewayFirewallDisabledRuleGroupArgs =
        ApplicationGatewayFirewallDisabledRuleGroupArgs(
            ruleGroupName = ruleGroupName ?: throw PulumiNullFieldException("ruleGroupName"),
            rules = rules,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewayFirewallDisabledRuleGroupArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewayFirewallDisabledRuleGroupArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Allows to disable rules within a rule group or an entire rule group.
 * @property ruleGroupName The name of the rule group that will be disabled.
 * @property rules The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
 */
public data class ApplicationGatewayFirewallDisabledRuleGroupArgs(
    public val ruleGroupName: Output<String>,
    public val rules: Output<List<Int>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewayFirewallDisabledRuleGroupArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.ApplicationGatewayFirewallDisabledRuleGroupArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewayFirewallDisabledRuleGroupArgs.builder()
            .ruleGroupName(ruleGroupName.applyValue({ args0 -> args0 }))
            .rules(rules?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ApplicationGatewayFirewallDisabledRuleGroupArgs].
 */
@PulumiTagMarker
public class ApplicationGatewayFirewallDisabledRuleGroupArgsBuilder internal constructor() {
    private var ruleGroupName: Output<String>? = null

    private var rules: Output<List<Int>>? = null

    /**
     * @param value The name of the rule group that will be disabled.
     */
    @JvmName("togvjhenpslondkb")
    public suspend fun ruleGroupName(`value`: Output<String>) {
        this.ruleGroupName = value
    }

    /**
     * @param value The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
     */
    @JvmName("frkqmcdmmustkeqb")
    public suspend fun rules(`value`: Output<List<Int>>) {
        this.rules = value
    }

    @JvmName("fhjjelvjgurwnigi")
    public suspend fun rules(vararg values: Output<Int>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
     */
    @JvmName("ccuhlynebxjjvhdc")
    public suspend fun rules(values: List<Output<Int>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value The name of the rule group that will be disabled.
     */
    @JvmName("kcssvhihgmygsnmt")
    public suspend fun ruleGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleGroupName = mapped
    }

    /**
     * @param value The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
     */
    @JvmName("kbqrtdiinydqucql")
    public suspend fun rules(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param values The list of rules that will be disabled. If null, all rules of the rule group will be disabled.
     */
    @JvmName("vkclqiaalakfopqp")
    public suspend fun rules(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): ApplicationGatewayFirewallDisabledRuleGroupArgs =
        ApplicationGatewayFirewallDisabledRuleGroupArgs(
            ruleGroupName = ruleGroupName ?: throw PulumiNullFieldException("ruleGroupName"),
            rules = rules,
        )
}
